﻿using System.Windows;
using System.Windows.Controls;

namespace Matrix
{
    public class GridDefinition
    {
        // Eigenschaften
        public static readonly DependencyProperty RowCountProperty =
            DependencyProperty.RegisterAttached("RowCount", typeof(int), typeof(GridDefinition), new PropertyMetadata(1, RowCountChanged));
        public static readonly DependencyProperty ColumnCountProperty =
            DependencyProperty.RegisterAttached("ColumnCount", typeof(int), typeof(GridDefinition), new PropertyMetadata(1, ColumnCountChanged));
        public static readonly DependencyProperty RowHeightProperty =
            DependencyProperty.RegisterAttached("RowHeight", typeof(double), typeof(GridDefinition), new PropertyMetadata(0.0, RowHeightChanged));
        public static readonly DependencyProperty ColumnWidthProperty =
            DependencyProperty.RegisterAttached("ColumnWidth", typeof(double), typeof(GridDefinition), new PropertyMetadata(0.0, ColumnWidthChanged));

        // Methoden
        public static int GetRowCount(DependencyObject obj)
        {
            return (int)obj.GetValue(RowCountProperty);
        }
        public static void SetRowCount(DependencyObject obj, int value)
        {
            obj.SetValue(RowCountProperty, value);
        }
        public static int GetColumnCount(DependencyObject obj)
        {
            return (int)obj.GetValue(ColumnCountProperty);
        }
        public static void SetColumnCount(DependencyObject obj, int value)
        {
            obj.SetValue(ColumnCountProperty, value);
        }
        public static double GetRowHeight(DependencyObject obj)
        {
            return (double)obj.GetValue(RowHeightProperty);
        }
        public static void SetRowHeight(DependencyObject obj, double value)
        {
            obj.SetValue(RowHeightProperty, value);
        }
        public static double GetColumnWidth(DependencyObject obj)
        {
            return (double)obj.GetValue(ColumnWidthProperty);
        }
        public static void SetColumnWidth(DependencyObject obj, double value)
        {
            obj.SetValue(ColumnWidthProperty, value);
        }

        private static void RowCountChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            GenerateRows((Grid)d, (int)e.NewValue, GetRowHeight(d));
        }
        private static void ColumnCountChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            GenerateColumns((Grid)d, (int)e.NewValue, GetColumnWidth(d));
        }
        private static void RowHeightChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            GenerateRows((Grid)d, GetRowCount(d), (double)e.NewValue);
        }
        private static void ColumnWidthChanged(DependencyObject d, DependencyPropertyChangedEventArgs e)
        {
            GenerateColumns((Grid)d, GetColumnCount(d), (double)e.NewValue);
        }

        private static void GenerateRows(Grid g, int Count, double Height)
        {
            // Angegebene Anzahl RowDefinitions erzeugen
            g.RowDefinitions.Clear();
            for (int i = 0; i < Count; i++)
                g.RowDefinitions.Add(new RowDefinition() { Height = new GridLength(Height) });
        }
        private static void GenerateColumns(Grid g, int Count, double Width)
        {
            // Angegebene Anzahl ColumnDefinitions erzeugen
            g.ColumnDefinitions.Clear();
            for (int i = 0; i < Count; i++)
                g.ColumnDefinitions.Add(new ColumnDefinition() { Width = new GridLength(Width) });
        }
    }
}